@@ -1,5 +1,7 @@
 """
-Main interface for resource-groups service literal definitions.
+Type annotations for resource-groups service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/literals.html)
 
 Usage::
 
